==> kubernetes-model-kustomize-6.8.1-sources.jar: io/fabric8/kubernetes/api/model/kustomize/v1beta1/GeneratorOptionsFluent.java <==
package io.fabric8.kubernetes.api.model.kustomize.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class GeneratorOptionsFluent<A extends GeneratorOptionsFluent<A>> extends BaseFluent<A>{
  public GeneratorOptionsFluent() {
  }
  public GeneratorOptionsFluent(GeneratorOptions instance) {
    instance = (instance != null ? instance : new GeneratorOptions());

    if (instance != null) {
      this.withAnnotations(instance.getAnnotations());
      this.withDisableNameSuffixHash(instance.getDisableNameSuffixHash());
      this.withImmutable(instance.getImmutable());
      this.withLabels(instance.getLabels());
      this.withAnnotations(instance.getAnnotations());
      this.withDisableNameSuffixHash(instance.getDisableNameSuffixHash());
      this.withImmutable(instance.getImmutable());
      this.withLabels(instance.getLabels());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private Map<String,String> annotations;
  private Boolean disableNameSuffixHash;
  private Boolean immutable;
  private Map<String,String> labels;
  private Map<String,Object> additionalProperties;
  public A addToAnnotations(String key,String value) {
    if(this.annotations == null && key != null && value != null) { this.annotations = new LinkedHashMap(); }
    if(key != null && value != null) {this.annotations.put(key, value);} return (A)this;
  }
  public A addToAnnotations(Map<String,String> map) {
    if(this.annotations == null && map != null) { this.annotations = new LinkedHashMap(); }
    if(map != null) { this.annotations.putAll(map);} return (A)this;
  }
  public A removeFromAnnotations(String key) {
    if(this.annotations == null) { return (A) this; }
    if(key != null && this.annotations != null) {this.annotations.remove(key);} return (A)this;
  }
  public A removeFromAnnotations(Map<String,String> map) {
    if(this.annotations == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.annotations != null){this.annotations.remove(key);}}} return (A)this;
  }
  public Map<String,String> getAnnotations() {
    return this.annotations;
  }
  public <K,V>A withAnnotations(Map<String,String> annotations) {
    if (annotations == null) { this.annotations =  null;} else {this.annotations = new LinkedHashMap(annotations);} return (A) this;
  }
  public boolean hasAnnotations() {
    return this.annotations != null;
  }
  public Boolean getDisableNameSuffixHash() {
    return this.disableNameSuffixHash;
  }
  public A withDisableNameSuffixHash(Boolean disableNameSuffixHash) {
    this.disableNameSuffixHash=disableNameSuffixHash; return (A) this;
  }
  public boolean hasDisableNameSuffixHash() {
    return this.disableNameSuffixHash != null;
  }
  public Boolean getImmutable() {
    return this.immutable;
  }
  public A withImmutable(Boolean immutable) {
    this.immutable=immutable; return (A) this;
  }
  public boolean hasImmutable() {
    return this.immutable != null;
  }
  public A addToLabels(String key,String value) {
    if(this.labels == null && key != null && value != null) { this.labels = new LinkedHashMap(); }
    if(key != null && value != null) {this.labels.put(key, value);} return (A)this;
  }
  public A addToLabels(Map<String,String> map) {
    if(this.labels == null && map != null) { this.labels = new LinkedHashMap(); }
    if(map != null) { this.labels.putAll(map);} return (A)this;
  }
  public A removeFromLabels(String key) {
    if(this.labels == null) { return (A) this; }
    if(key != null && this.labels != null) {this.labels.remove(key);} return (A)this;
  }
  public A removeFromLabels(Map<String,String> map) {
    if(this.labels == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.labels != null){this.labels.remove(key);}}} return (A)this;
  }
  public Map<String,String> getLabels() {
    return this.labels;
  }
  public <K,V>A withLabels(Map<String,String> labels) {
    if (labels == null) { this.labels =  null;} else {this.labels = new LinkedHashMap(labels);} return (A) this;
  }
  public boolean hasLabels() {
    return this.labels != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    GeneratorOptionsFluent that = (GeneratorOptionsFluent) o;
    if (!java.util.Objects.equals(annotations, that.annotations)) return false;

    if (!java.util.Objects.equals(disableNameSuffixHash, that.disableNameSuffixHash)) return false;

    if (!java.util.Objects.equals(immutable, that.immutable)) return false;

    if (!java.util.Objects.equals(labels, that.labels)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(annotations,  disableNameSuffixHash,  immutable,  labels,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (annotations != null && !annotations.isEmpty()) { sb.append("annotations:"); sb.append(annotations + ","); }
    if (disableNameSuffixHash != null) { sb.append("disableNameSuffixHash:"); sb.append(disableNameSuffixHash + ","); }
    if (immutable != null) { sb.append("immutable:"); sb.append(immutable + ","); }
    if (labels != null && !labels.isEmpty()) { sb.append("labels:"); sb.append(labels + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public A withDisableNameSuffixHash() {
    return withDisableNameSuffixHash(true);
  }
  public A withImmutable() {
    return withImmutable(true);
  }
  
}

==> kubernetes-model-kustomize-6.9.0-sources.jar: io/fabric8/kubernetes/api/model/kustomize/v1beta1/GeneratorOptionsFluent.java <==
package io.fabric8.kubernetes.api.model.kustomize.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class GeneratorOptionsFluent<A extends GeneratorOptionsFluent<A>> extends BaseFluent<A>{
  public GeneratorOptionsFluent() {
  }
  
  public GeneratorOptionsFluent(GeneratorOptions instance) {
    this.copyInstance(instance);
  }
  private Map<String,String> annotations;
  private Boolean disableNameSuffixHash;
  private Boolean immutable;
  private Map<String,String> labels;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(GeneratorOptions instance) {
    instance = (instance != null ? instance : new GeneratorOptions());
  
    if (instance != null) {
        this.withAnnotations(instance.getAnnotations());
        this.withDisableNameSuffixHash(instance.getDisableNameSuffixHash());
        this.withImmutable(instance.getImmutable());
        this.withLabels(instance.getLabels());
        this.withAnnotations(instance.getAnnotations());
        this.withDisableNameSuffixHash(instance.getDisableNameSuffixHash());
        this.withImmutable(instance.getImmutable());
        this.withLabels(instance.getLabels());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public A addToAnnotations(String key,String value) {
    if(this.annotations == null && key != null && value != null) { this.annotations = new LinkedHashMap(); }
    if(key != null && value != null) {this.annotations.put(key, value);} return (A)this;
  }
  
  public A addToAnnotations(Map<String,String> map) {
    if(this.annotations == null && map != null) { this.annotations = new LinkedHashMap(); }
    if(map != null) { this.annotations.putAll(map);} return (A)this;
  }
  
  public A removeFromAnnotations(String key) {
    if(this.annotations == null) { return (A) this; }
    if(key != null && this.annotations != null) {this.annotations.remove(key);} return (A)this;
  }
  
  public A removeFromAnnotations(Map<String,String> map) {
    if(this.annotations == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.annotations != null){this.annotations.remove(key);}}} return (A)this;
  }
  
  public Map<String,String> getAnnotations() {
    return this.annotations;
  }
  
  public <K,V>A withAnnotations(Map<String,String> annotations) {
    if (annotations == null) { this.annotations =  null;} else {this.annotations = new LinkedHashMap(annotations);} return (A) this;
  }
  
  public boolean hasAnnotations() {
    return this.annotations != null;
  }
  
  public Boolean getDisableNameSuffixHash() {
    return this.disableNameSuffixHash;
  }
  
  public A withDisableNameSuffixHash(Boolean disableNameSuffixHash) {
    this.disableNameSuffixHash=disableNameSuffixHash; return (A) this;
  }
  
  public boolean hasDisableNameSuffixHash() {
    return this.disableNameSuffixHash != null;
  }
  
  public Boolean getImmutable() {
    return this.immutable;
  }
  
  public A withImmutable(Boolean immutable) {
    this.immutable=immutable; return (A) this;
  }
  
  public boolean hasImmutable() {
    return this.immutable != null;
  }
  
  public A addToLabels(String key,String value) {
    if(this.labels == null && key != null && value != null) { this.labels = new LinkedHashMap(); }
    if(key != null && value != null) {this.labels.put(key, value);} return (A)this;
  }
  
  public A addToLabels(Map<String,String> map) {
    if(this.labels == null && map != null) { this.labels = new LinkedHashMap(); }
    if(map != null) { this.labels.putAll(map);} return (A)this;
  }
  
  public A removeFromLabels(String key) {
    if(this.labels == null) { return (A) this; }
    if(key != null && this.labels != null) {this.labels.remove(key);} return (A)this;
  }
  
  public A removeFromLabels(Map<String,String> map) {
    if(this.labels == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.labels != null){this.labels.remove(key);}}} return (A)this;
  }
  
  public Map<String,String> getLabels() {
    return this.labels;
  }
  
  public <K,V>A withLabels(Map<String,String> labels) {
    if (labels == null) { this.labels =  null;} else {this.labels = new LinkedHashMap(labels);} return (A) this;
  }
  
  public boolean hasLabels() {
    return this.labels != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    GeneratorOptionsFluent that = (GeneratorOptionsFluent) o;
    if (!java.util.Objects.equals(annotations, that.annotations)) return false;
  
    if (!java.util.Objects.equals(disableNameSuffixHash, that.disableNameSuffixHash)) return false;
  
    if (!java.util.Objects.equals(immutable, that.immutable)) return false;
  
    if (!java.util.Objects.equals(labels, that.labels)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(annotations,  disableNameSuffixHash,  immutable,  labels,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (annotations != null && !annotations.isEmpty()) { sb.append("annotations:"); sb.append(annotations + ","); }
    if (disableNameSuffixHash != null) { sb.append("disableNameSuffixHash:"); sb.append(disableNameSuffixHash + ","); }
    if (immutable != null) { sb.append("immutable:"); sb.append(immutable + ","); }
    if (labels != null && !labels.isEmpty()) { sb.append("labels:"); sb.append(labels + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
  public A withDisableNameSuffixHash() {
    return withDisableNameSuffixHash(true);
  }
  
  public A withImmutable() {
    return withImmutable(true);
  }
  

}
